@@ -29,7 +29,7 @@ dyn_link <- function(text,
   return(link(text, url))
 }
 # Other variables
-admiral_homepage <- "https://pharmaverse.github.io/admiral"
+admiral_homepage <- "https://pharmaverse.github.io/admiral/cran-release"
 
 ## -----------------------------------------------------------------------------
 library(admiral)
